# 1costingfe

Name-reservation alias for [costingfe](https://pypi.org/project/costingfe/),
the 1costingFE fusion power plant costing framework. Installing this package
installs `costingfe`; the import name is `costingfe`.

Project home: https://github.com/1cFE/1costingfe
